==> libmp3splt-0.8.2.tar.gz: libmp3splt-0.8.2/src/client.h <==
/**********************************************************
 *
 * libmp3splt -- library based on mp3splt,
 *               for mp3/ogg splitting without decoding
 *
 * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
 * Copyright (c) 2005-2013 Alexandru Munteanu - m@ioalex.net
 *
 * http://mp3splt.sourceforge.net
 *
 *********************************************************/

/**********************************************************
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 *
 *********************************************************/

#ifndef SPLT_CLIENT_H

int splt_c_put_split_file(splt_state *state, const char *filename);
void splt_c_put_progress_text(splt_state *state,int type);

void splt_c_put_info_message_to_client(splt_state *state,
    const char *message, ...);
void splt_c_put_debug_message_to_client(splt_state *state,
    const char *message, ...);

void splt_c_update_progress(splt_state *state, double current_point,
    double total_points, int progress_stage,
    float progress_start, int refresh_rate);

#define SPLT_CLIENT_H

#endif

==> libmp3splt-0.9.1a.tar.gz: libmp3splt-0.9.1a/src/client.h <==
/**********************************************************
 *
 * libmp3splt -- library based on mp3splt,
 *               for mp3/ogg splitting without decoding
 *
 * Copyright (c) 2002-2005 M. Trotta - <mtrotta@users.sourceforge.net>
 * Copyright (c) 2005-2013 Alexandru Munteanu - m@ioalex.net
 *
 * http://mp3splt.sourceforge.net
 *
 *********************************************************/

/**********************************************************
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 *
 *********************************************************/

#ifndef SPLT_CLIENT_H

int splt_c_put_split_file(splt_state *state, const char *filename);
void splt_c_put_progress_text(splt_state *state,int type);

void splt_c_put_info_message_to_client(splt_state *state, const char *message, ...);
void splt_c_put_warning_message_to_client(splt_state *state, const char *message, ...);
void splt_c_put_debug_message_to_client(splt_state *state, const char *message, ...);

void splt_c_update_progress(splt_state *state, double current_point,
    double total_points, int progress_stage, float progress_start, int refresh_rate);

#define SPLT_CLIENT_H

#endif
